@@ -25,8 +25,8 @@ class DispatchClient:
             'data': data
         }
 
-        r.lpush(service_queue, json.dumps(request, ensure_ascii=False))
-        result = r.brpop(reply_to, timeout=timeout)
+        r.rpush(service_queue, json.dumps(request, ensure_ascii=False))
+        result = r.blpop(reply_to, timeout=timeout)
         if result and result[0] == reply_to:
             response = DispatchResponseModel.parse_obj(json.loads(result[1]))
             if response.correlation_id == correlation_id and response.status == DispatchResponseStatus.OK:
